Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(867)

Unified Diff: chrome/browser/extensions/extensions_service.h

Issue 243001: Implement Browser Actions extensions.... (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: '' Created 11 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/extensions/extensions_service.h
===================================================================
--- chrome/browser/extensions/extensions_service.h (revision 27027)
+++ chrome/browser/extensions/extensions_service.h (working copy)
@@ -102,10 +102,14 @@
return GetExtensionByIdInternal(id, true, false);
}
- // Retrieves a vector of all page actions, irrespective of which
- // extension they belong to.
- std::vector<PageAction*> GetPageActions() const;
+ // Retrieves a vector of all page actions, irrespective of which extension
+ // they belong to.
+ std::vector<ContextualAction*> GetPageActions() const;
+ // Retrieves a vector of all browser actions, irrespective of which extension
+ // they belong to.
+ std::vector<ContextualAction*> GetBrowserActions() const;
+
// Install the extension file at |extension_path|. Will install as an
// update if an older version is already installed.
// For fresh installs, this method also causes the extension to be
@@ -232,6 +236,11 @@
DictionaryValue* manifest, const std::string& id,
const FilePath& path, Extension::Location location);
+ // Retrieves a vector of all page actions or browser actions, irrespective of
+ // which extension they belong to.
+ std::vector<ContextualAction*> GetContextualActions(
+ ContextualAction::ContextualActionType action_type) const;
+
// The profile this ExtensionsService is part of.
Profile* profile_;

Powered by Google App Engine
This is Rietveld 408576698